Listings
========

This shows listings from compiler internal registries  (e.g. lowering
definitions).  The information is provided as developer reference.
When possible, links to source code are provided via github links.

New style listings
------------------

The following listings are generated from ``numba.help.inspector.write_listings()``. Users can run ``python -m numba.help.inspector --format=rst <package>`` to recreate the documentation.

.. toctree::
   :maxdepth: 2

   autogen_builtins_listing.rst
   autogen_math_listing.rst
   autogen_cmath_listing.rst
   autogen_numpy_listing.rst


Old style listings
------------------

.. toctree::
   :maxdepth: 2

   autogen_lower_listing.rst

